/**
 * A logger backed by [pino](https://getpino.io/)
 *
 * The default log level is `info`, but you can change it passing a level
 * string set to one of: `"trace"`, `"debug"`, `"info"`, `"warn"`,
 * `"error"`, or `"fatal"`.
 *
 * ```js
 * app.log.debug("…so is this");
 * app.log.trace("Now we're talking");
 * app.log.info("I thought you should know…");
 * app.log.warn("Woah there");
 * app.log.error("ETOOMANYLOGS");
 * app.log.fatal("Goodbye, cruel world!");
 * ```
 */
import { pino } from "pino";
import { getTransformStream } from "@probot/pino";
import { rebindLog } from "./rebind-log.js";
export function getLog(options = {}) {
    const { level, logMessageKey, ...getTransformStreamOptions } = options;
    const pinoOptions = {
        level: level || "info",
        name: "probot",
        messageKey: logMessageKey || "msg",
    };
    const transform = getTransformStream(getTransformStreamOptions);
    transform.pipe(pino.destination(1));
    return rebindLog(pino(pinoOptions, transform));
}
//# sourceMappingURL=get-log.js.map