import Bottleneck from "bottleneck";
import { Redis } from "ioredis";
export function getOctokitThrottleOptions(options) {
    let { log, redisConfig } = options;
    const throttlingOptions = {
        onRateLimit: (retryAfter, options) => {
            log.warn(`Request quota exhausted for request ${options.method} ${options.url}`);
            // Retry twice after hitting a rate limit error, then give up
            if (options.request.retryCount <= 2) {
                log.info(`Retrying after ${retryAfter} seconds!`);
                return true;
            }
            return false;
        },
        onSecondaryRateLimit: (_retryAfter, options) => {
            // does not retry, only logs a warning
            log.warn(`Secondary quota detected for request ${options.method} ${options.url}`);
        },
    };
    if (!redisConfig)
        return throttlingOptions;
    const connection = new Bottleneck.IORedisConnection({
        client: getRedisClient(options),
    });
    connection.on("error", (error) => {
        log.error(Object.assign(error, { source: "bottleneck" }));
    });
    throttlingOptions.Bottleneck = Bottleneck;
    throttlingOptions.connection = connection;
    return throttlingOptions;
}
function getRedisClient({ redisConfig }) {
    if (redisConfig)
        return new Redis(redisConfig);
}
//# sourceMappingURL=get-octokit-throttle-options.js.map